@@ -39,7 +39,7 @@ Array of subtables in the kerning table
 
 Each subtable has a number of instance variables.
 
-=item kerns
+=item kern
 
 A two level hash array containing kerning values. The indexing is left
 value and then right value. In the case of type 2 tables, the indexing
@@ -243,6 +243,31 @@ sub out
     $self;
 }
 
+
+=head2 $t->XML_element($context, $depth, $key, $value)
+
+Handles outputting the kern hash into XML a little more tidily
+
+=cut
+
+sub XML_element
+{
+    my ($self) = shift;
+    my ($context, $depth, $key, $value) = @_;
+    my ($fh) = $context->{'fh'};
+    my ($f, $l);
+
+    return $self->SUPER::XML_element(@_) unless ($key eq 'kern');
+    $fh->print("$depth<kern-table>\n");
+    foreach $f (sort {$a <=> $b} keys %{$value})
+    {
+        foreach $l (sort {$a <=> $b} keys %{$value->{$f}})
+        { $fh->print("$depth$context->{'indent'}<adjust first='$f' last='$l' dist='$value->{$f}{$l}'/>\n"); }
+    }
+    $fh->print("$depth</kern-table>\n");
+    $self;
+}
+
 1;
 
 =head1 BUGS
